#!/usr/bin/tclsh
#package require ncgi
#package require html

source ncgi.tcl
source html.tcl

# configuration variables
set IMAGE_PATH "/knox/images"
set knoxport "/dev/ttyb"

# Labels for the web page, both column and row labels
set columnLabels {"Output/Input" "Video Mixer 2" "Projector Left" "Projector Right" "VCR" "CVN" "PC" "SUN" "Stage Monitor"}
set rowLabels {"Mixer 1" "Mixer 2" "DVD" "VCR" "CVN" "n/c" "Satellite" "n/c"}

# output header and title and stylesheet information
ncgi::header
ncgi::input
html::init

set title "Knox Interface"
html::headTag "link type=\"text/css\" rel=\"stylesheet\" href=\"style.css\""
puts [html::head $title]
puts [html::bodyTag]

# set up knox serial port
set serial [open $knoxport r+]
fconfigure $serial -mode "9600,n,8,1"
fconfigure $serial -blocking 0 -buffering none


#
# Knox command overview:
#
# in the following, x=output, y=input
#
# Bxy\r to route video and audio
# Vxy\r to route video alone
# Axy\r to route audio alone
# Bxyz\r to route video and audio from different inputs, x = output,
#        y is video input, z is audio input
# turn off a crosspoint by routing it to input zero
#        B10 turns off the video and audio to output 1

# Sn\r to save it in 1-8
# Rn\r to restore it from 1-8

# D\r to read the crosspoint status
# D0\r to read condensed crosspoint status


# test to see if this is return from a submit, so have to do output to knox
if {[llength [ncgi::nvlist]] != 0} {

    # pull out the button name from the passed variables
    foreach {button} [ncgi::nvlist] {break}

    # button name is output to send
    set knox_output [string range $button 0 [expr [string length $button]-3]]

    # output to Knox
    puts -nonewline $serial "$knox_output\r"
    after 100

}



puts "<form method=post action=knox.cgi>"
puts "<table cellspacing=3 cellpadding=5>"

array set myarray {}

# label the rows
set x 1
foreach label $rowLabels {
    set myarray(0,$x) $label
    set x [expr $x+1]
}

# label the columns
set y 0
foreach label $columnLabels {
    set myarray($y,0) $label
    set y [expr $y+1]
}


# default array to 0
for {set y 1} {$y < 9} {incr y} {
    for {set x 1} {$x < 9} {incr x} {
	set myarray($y,$x) "0"
    }
}

# get input from knox
puts -nonewline $serial "D0\r"
after 100
set input [read $serial]

#parse the "D0" command response for layout

set inputlist [split $input "\n"]

foreach i $inputlist {
    
    if {[string compare $i "D0"] != 0} {
	if {[string compare $i "DONE"] != 0} {
	    if {[string compare $i ""] != 0} {
		if {[string compare $i " "] != 0} {
		    
		    # stripped out unnecessary lines,
		    # parse this out and set the array 
		    
		    set y [string index $i 0]
		    set x [string index $i 2]
		    
		    if {$x != 0} {
			set myarray($y,$x) "1"
		    }
		}
	    }
	}
    }

}


# generate the table
for {set y 0} {$y < 9} {incr y} {
    puts "<tr>"

    # for every row

    for {set x 0} {$x < 9} {incr x} {

	# for every cell in the row

	# set class for td for stylesheets

	set class "regular"
	if {($x == 0) || ($y == 0)} {
	    set class "label"
	}
	puts "<td class=$class>"

	# show filled or empty circle graphic, depending on value of array

	if {$myarray($y,$x) == 0} {
	    set letter "B"
	    set src "$IMAGE_PATH/empty.gif"
	    set input "$letter$y$x"
	    puts "<input type=image name=\"$input\" src=\"$src\" border=0>"
	} elseif {$myarray($y,$x) == 1} {
	    set letter "B"
	    set z "0"
	    set src "$IMAGE_PATH/filled.gif"
	    set input "$letter$y$z"
	    puts "<input type=image name=\"$input\" src=\"$src\" border=0>"
	} else {
	    puts $myarray($y,$x)
	}

	puts "</td>"
    }
    puts "</tr>"
}

puts "</table>"
puts "</form>"

puts [html::end]
