#############################################################################
# Local --- This script is used to get the local environment value 
#
# namespace: Local
#
# proc:
#      Local::checkOs      get the OS information
#      Local::init         initialize the local environment value
#      Local::getIP        get the IP address of the local host
#      Local::ipChecking   check whether IP changed every ... seconds
#
# Creation date: 05/15/1999 
# Last modified: 09/25/2000
# @Author: Xiaotao Wu
#############################################################################

#============================================================================
# Structure of the file
#
#============================================================================

#----------------------------------------------------------------------------
# Namespace declaration
#
# namespace Local
#
# host:      current host name
# domain:    current domain name
# os:        the operating system of the machine
# ip:        the ip address of the machine
# username:  the current username
# qcard:     whether we have quicknet card or not, 1 -- have, 0 -- none
# qcchan:    quicknet card channel if we have quicknet card
#----------------------------------------------------------------------------
namespace eval Local {
  variable host
  variable domain
  variable os
  variable ip
  variable username
  variable home
  variable qcard
  variable qcchan
}

#----------------------------------------------------------------------------
# Local::init
#
# Setup the local environment value by call system functions
#----------------------------------------------------------------------------
proc Local::init {} {
  variable host
  variable domain
  variable os
  variable ip
  variable username
  variable home
  variable qcard
  variable qcchan

  set host [exec hostname]
  set domain ""
  set os [exec uname]
  set ips [exec /sbin/ifconfig eth0 | grep inet]
  for {set ip "127.0.0.1"} {$ip == "127.0.0.1"} {} {
    set ip1 [lindex [split $ips ":"] 1]
    set ip [lindex [split $ip1 " "] 0]
    set ips [string range $ips [expr [string first "\n" $ips]+1] end]
  }

  set username [exec whoami]
  set home "" 
  	#$::env(HOME)

  if {$domain == ""} {
    set domain $ip
  }
  if {$username == ""}  {
    set username "-"
  } 
  # If there is space in the username, replace it as "_"
  set i [string first " " $username 0]
  while {$i != -1} {
    set username [string replace $username $i $i "_"]
    set i [string first " " $username $i]
  }
}
